within ;
model SquareCardiacOutput
  Modelica.Blocks.Sources.Pulse pulse(
    width=30,
    period(displayUnit="min") = 60/75,
    amplitude=0.001*5/(0.3*60))
    annotation (Placement(transformation(extent={{-88,60},{-68,80}})));
  Physiolibrary.Hydraulic.Sources.UnlimitedPump unlimitedPump(
      useSolutionFlowInput=true)
    annotation (Placement(transformation(extent={{-66,20},{-46,40}})));
  Physiolibrary.Hydraulic.Components.ElasticVessel elasticVessel(Compliance(
        displayUnit="m3/Pa") = 1.2601034474207e-08)
    annotation (Placement(transformation(extent={{-24,20},{-4,40}})));
  Physiolibrary.Hydraulic.Components.Conductor conductor(Conductance(
        displayUnit="m3/(Pa.s)") = 6.2505131320471e-09)
    annotation (Placement(transformation(extent={{12,20},{32,40}})));
  Physiolibrary.Hydraulic.Sources.UnlimitedVolume unlimitedVolume
    annotation (Placement(transformation(extent={{82,20},{62,40}})));
equation
  connect(pulse.y, unlimitedPump.solutionFlow) annotation (Line(
      points={{-67,70},{-56,70},{-56,34}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(unlimitedPump.q_out, elasticVessel.q_in) annotation (Line(
      points={{-46,30},{-14,30}},
      color={0,0,0},
      thickness=1,
      smooth=Smooth.None));
  connect(elasticVessel.q_in, conductor.q_in) annotation (Line(
      points={{-14,30},{12,30}},
      color={0,0,0},
      thickness=1,
      smooth=Smooth.None));
  connect(conductor.q_out, unlimitedVolume.y) annotation (Line(
      points={{32,30},{62,30}},
      color={0,0,0},
      thickness=1,
      smooth=Smooth.None));
  annotation (uses(Physiolibrary(version="2.2.0"), Modelica(version="3.2.1")),
      Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{
            100,100}}), graphics));
end SquareCardiacOutput;
